@@ -26,101 +26,27 @@
 #' @description This class inherits from the \code{\link{Instance}} class and
 #' implements the functions of extracting the text and the date of an ytbid type file.
 #'
-#' @docType class
-#'
-#' @format NULL
-#'
-#' @section Constructor:
-#' \code{ExtractorYtbid$new(path,
-#'                          cachePath = NULL)}
-#' \itemize{
-#' \item{\emph{Arguments:}}{
-#' \itemize{
-#' \item{\strong{path:}}{
-#' (\emph{character}) path of the ytbid type file.
-#' }
-#' \item{\strong{cachePath:}}{
-#' (\emph{character}) path of the cache location. If it is NULL, checks if is
-#' defined in the \strong{"cache.youtube.path"} field of
-#' \emph{\link{bdpar.Options}} variable.
-#' }
-#' }
-#' }
-#' }
-#'
 #' @section Details:
-#' YouTube conection is handled through the \code{\link{Connections}} class
+#' YouTube connection is handled through the \code{\link{Connections}} class
 #' which loads the YouTube API credentials from the \emph{{bdpar.Options}} object.
-#' Additionally, to increase the processing speed, each youtube query is stored
+#' Additionally, to increase the processing speed, each Youtube query is stored
 #' in a cache to avoid the execution of duplicated queries. To enable this option,
 #' cache location should be in the \strong{"cache.youtube.path"} field of
 #' \emph{\link{bdpar.Options}} variable. This variable has to be the
-#' path to store the comments and it is neccesary that it has two folder named:
+#' path to store the comments and it is necessary that it has two folder named:
 #' "_spam_" and "_ham_"
 #'
 #' @section Inherit:
 #' This class inherits from \code{\link{Instance}} and implements the
 #' \code{obtainSource} and \code{obtainDate} abstracts functions.
 #'
-#' @section Methods:
-#' \itemize{
-#' \item{\bold{obtainId:}}{
-#' obtains the id of the ytbid. Read the id of the file indicated
-#' in the variable path.
-#' \itemize{
-#' \item{\emph{Usage:}}{
-#' \code{obtainId()}
-#' }
-#' }
-#' }
-#' \item{\bold{getId:}}{
-#' gets of comment ID.
-#' \itemize{
-#' \item{\emph{Usage:}}{
-#' \code{getId()}
-#' }
-#' \item{\emph{Value:}}{
-#' value of comment ID.
-#' }
-#' }
-#' }
-#' \item{\bold{obtainDate:}}{
-#' obtains the date from a specific comment ID. If the comment has been previously
-#' cached the comment date is loaded from cache path. Otherwise, the request is
-#' perfomed using YouTube API and the date is then formatted to the established
-#' standard.
-#' \itemize{
-#' \item{\emph{Usage:}}{
-#' \code{obtainDate()}
-#' }
-#' }
-#' }
-#' \item{\bold{obtainSource:}}{
-#' obtains the source from a specific comment ID. If the comment has previously
-#' been cached the source is loaded from cache path. Otherwise, the request is
-#' performed using on YouTube API.
-#' \itemize{
-#' \item{\emph{Usage:}}{
-#' \code{obtainSource()}
-#' }
-#' }
-#' }
-#' }
-#'
-#' @section Private fields:
-#' \itemize{
-#' \item{\bold{id:}}{
-#'  (\emph{character}) ID of comment.
-#' }
-#' }
-#'
 #' @seealso \code{\link{bdpar.Options}}, \code{\link{Connections}},
 #'          \code{\link{ExtractorEml}}, \code{\link{ExtractorSms}},
 #'          \code{\link{ExtractorTwtid}}, \code{\link{Instance}}
 #'
 #' @keywords NULL
 #'
-#' @import pipeR R6
+#' @import R6
 #' @export ExtractorYtbid
 
 ExtractorYtbid <- R6Class(
@@ -130,56 +56,76 @@ ExtractorYtbid <- R6Class(
   inherit = Instance,
 
   public = list(
-
+    #'
+    #' @description Creates a \code{\link{ExtractorYtbid}} object.
+    #'
+    #' @param path A \code{\link{character}} value. Path of the ytbid file.
+    #' @param cachePath A \code{\link{character}} value. Path of the cache
+    #' location. If it is NULL, checks if is defined in the
+    #' \strong{"cache.youtube.path"} field of \code{\link{bdpar.Options}}
+    #' variable.
+    #'
     initialize = function(path,
                           cachePath = NULL) {
 
       if (!"character" %in% class(path)) {
-        stop("[ExtractorYtbid][initialize][Error] ",
-             "Checking the type of the 'path' variable: ",
-             class(path))
+        bdpar.log(message = paste0("Checking the type of the 'path' variable: ",
+                                   class(path)),
+                  level = "FATAL",
+                  className = class(self)[1],
+                  methodName = "initialize")
       }
 
-      path %>>%
-        super$initialize()
+      super$initialize(path)
 
       self$obtainId()
       #Singleton
-      Bdpar[["private_fields"]][["connections"]]$startConnectionWithYoutube()
+      Bdpar[["private_methods"]][["connections"]]()$startConnectionWithYoutube()
 
       if (is.null(cachePath)) {
-        if (!all(bdpar.Options$isSpecificOption("cache.youtube.path"),
-                 !is.null(bdpar.Options$get("cache.youtube.path")))) {
-          stop("[ExtractorYtbid][initialize][Error] Path of YouTube comments' ",
-               "cache is neither defined in initialize or in bdpar.Options")
+        if (!bdpar.Options$isSpecificOption("cache.youtube.path") ||
+            is.null(bdpar.Options$get("cache.youtube.path"))) {
+          bdpar.log(message = paste0("Path of YouTube comments' cache is ",
+                                     "neither defined in initialize or in bdpar.Options"),
+                    level = "FATAL",
+                    className = class(self)[1],
+                    methodName = "initialize")
         } else {
           cachePath <- bdpar.Options$get("cache.youtube.path")
         }
       }
 
       if (!"character" %in% class(cachePath)) {
-        stop("[ExtractorYtbid][initialize][Error] ",
-             "Checking the type of the 'cachePath' variable: ",
-             class(cachePath))
+        bdpar.log(message = paste0("Checking the type of the 'cachePath' variable: ",
+                                   class(cachePath)),
+                  level = "FATAL",
+                  className = class(self)[1],
+                  methodName = "initialize")
       }
 
       private$cachePath <- cachePath
-
-      return()
     },
-
+    #'
+    #' @description Obtains the ID of the specific Youtube's comment. Reads the ID
+    #' of the file indicated in the variable path.
+    #'
     obtainId = function() {
-
       private$id <- readLines(super$getPath(), warn = FALSE, n = 1)
-
-      return()
     },
-
+    #'
+    #' @description Gets the ID of an specific Youtube's comment.
+    #'
+    #' @return Value of Youtube's comment ID.
+    #'
     getId = function() {
-
-      return(private$id)
+      private$id
     },
-
+    #'
+    #' @description Obtains the date from a specific comment ID. If the comment
+    #' has been previously cached the comment date is loaded from cache path.
+    #' Otherwise, the request is perfomed using YouTube API and the date is then
+    #' formatted to the established standard.
+    #'
     obtainDate = function() {
 
       if (file.exists(
@@ -222,7 +168,7 @@ ExtractorYtbid <- R6Class(
         dateYtbid <- ""
         sourceYtbid <- ""
 
-        Bdpar[["private_fields"]][["connections"]]$checkRequestToYoutube()
+        Bdpar[["private_methods"]][["connections"]]()$checkRequestToYoutube()
 
         comment <- tryCatch(
 
@@ -232,18 +178,24 @@ ExtractorYtbid <- R6Class(
           ),
 
           warning = function(w) {
-            warning("[ExtractorYtbid][obtainDate][Warning] Date ytbid warning: ",
-                      self$getId(), " ", paste(w))
+            bdpar.log(message = paste0("Date ytbid warning: ", self$getId(),
+                                       " ", paste(w)),
+                      level = "WARN",
+                      className = class(self)[1],
+                      methodName = "obtainDate")
           },
 
           error = function(e) {
-            message("[ExtractorYtbid][obtainDate][Error] Date ytbid error: ",
-                      self$getId(), " ", paste(e))
+            bdpar.log(message = paste0("Date ytbid error: ", self$getId(),
+                                       " ", paste(w)),
+                      level = "ERROR",
+                      className = class(self)[1],
+                      methodName = "obtainDate")
           }
         )
       }
 
-      Bdpar[["private_fields"]][["connections"]]$addNumRequestToYoutube()
+      Bdpar[["private_methods"]][["connections"]]()$addNumRequestToYoutube()
 
       if (!is.null(comment) && is.data.frame(comment)) {
 
@@ -266,20 +218,25 @@ ExtractorYtbid <- R6Class(
           as.POSIXct(dateYtbid),
 
           warning = function(w) {
-            warning("[ExtractorYtbid][obtainDate][Warning] Date ytbid warning as.POSIXct: ",
-                      self$getId(), " ", paste(w))
+            bdpar.log(message = paste0("Date ytbid warning as.POSIXct: ",
+                                       self$getId(), " ", paste(w)),
+                      level = "WARN",
+                      className = class(self)[1],
+                      methodName = "obtainDate")
           },
 
           error = function(e) {
-            message("[ExtractorYtbid][obtainDate][Error] Date ytbid error as.POSIXct: ",
-                      self$getId(), " ", paste(e))
+            bdpar.log(message = paste0("Date ytbid error as.POSIXct: ",
+                                       self$getId(), " ", paste(e)),
+                      level = "ERROR",
+                      className = class(self)[1],
+                      methodName = "obtainDate")
           }
         )
 
         formatDateGeneric <- "%a %b %d %H:%M:%S %Z %Y"
-        format(StandardizedDate, formatDateGeneric) %>>%
-          as.character() %>>%
-            super$setDate()
+        super$setDate(as.character(format(StandardizedDate,
+                                          formatDateGeneric)))
 
       } else {
         super$setDate("")
@@ -310,8 +267,11 @@ ExtractorYtbid <- R6Class(
 
       error = function(e) {
 
-        message("[ExtractorYtbid][obtainDate][Error] exportJSON: ",
-                  self$getId(), " " , paste(e))
+        bdpar.log(message = paste0("exportJSON: ", self$getId(),
+                                   " " , paste(e)),
+                  level = "ERROR",
+                  className = class(self)[1],
+                  methodName = "obtainDate")
 
         lista <- list(source = "",
                       date = super$getDate())
@@ -332,10 +292,12 @@ ExtractorYtbid <- R6Class(
           sep = "\n"
         )
       })
-
-      return()
     },
-
+    #'
+    #' @description Obtains the source from a specific comment ID. If the
+    #' comment has previously been cached the source is loaded from cache path.
+    #' Otherwise, the request is performed using on YouTube API.
+    #'
     obtainSource = function() {
 
       if (file.exists(
@@ -368,11 +330,9 @@ ExtractorYtbid <- R6Class(
               !is.null(dataFromJsonFile[["source"]]) &&
                 dataFromJsonFile[["source"]] != "") {
 
-          dataFromJsonFile[["source"]] %>>%
-            super$setSource()
+          super$setSource(dataFromJsonFile[["source"]])
 
-          super$getSource() %>>%
-            super$setData()
+          super$setData(super$getSource())
 
           return()
         }
@@ -383,7 +343,7 @@ ExtractorYtbid <- R6Class(
         dateYtbid <- ""
         sourceYtbid <- ""
 
-        Bdpar[["private_fields"]][["connections"]]$checkRequestToYoutube()
+        Bdpar[["private_methods"]][["connections"]]()$checkRequestToYoutube()
 
         comment <- tryCatch(
 
@@ -393,18 +353,24 @@ ExtractorYtbid <- R6Class(
           ),
 
           warning = function(w) {
-            warning("[ExtractorYtbid][obtainSource][Warning] Source ytbid warning: ",
-                      self$getId(), " ", paste(w))
+            bdpar.log(message = paste0("Source ytbid warning: ",
+                                       self$getId(), " ", paste(w)),
+                      level = "WARN",
+                      className = class(self)[1],
+                      methodName = "obtainDate")
           },
 
           error = function(e) {
-            message("[ExtractorYtbid][obtainSource][Error] Source ytbid error: ",
-                      self$getId(), " ", paste(e))
+            bdpar.log(message = paste0("Source ytbid error: ",
+                                       self$getId(), " ", paste(e)),
+                      level = "ERROR",
+                      className = class(self)[1],
+                      methodName = "obtainSource")
           }
         )
       }
 
-      Bdpar[["private_fields"]][["connections"]]$addNumRequestToYoutube()
+      Bdpar[["private_methods"]][["connections"]]()$addNumRequestToYoutube()
 
       if (!is.null(comment) && is.data.frame(comment)) {
 
@@ -427,27 +393,32 @@ ExtractorYtbid <- R6Class(
           as.POSIXct(dateYtbid),
 
           warning = function(w) {
-            warning("[ExtractorYtbid][obtainSource][Warning] Date ytbid warning as.POSIXct: ",
-                      self$getId(), " " , paste(w))
+            bdpar.log(message = paste0("Date ytbid warning as.POSIXct: ",
+                                       self$getId(), " " , paste(w)),
+                      level = "WARN",
+                      className = class(self)[1],
+                      methodName = "obtainSource")
           },
 
           error = function(e) {
-            message("[ExtractorYtbid][obtainSource][Error] Date ytbid error as.POSIXct: ",
-                      self$getId(), " " , paste(e))
+            bdpar.log(message = paste0("Date ytbid error as.POSIXct: ",
+                                       self$getId(), " " , paste(e)),
+                      level = "ERROR",
+                      className = class(self)[1],
+                      methodName = "obtainSource")
           }
         )
 
         formatDateGeneric <- "%a %b %d %H:%M:%S %Z %Y"
 
-        dateYtbid <- as.character(format(StandardizedDate, formatDateGeneric))
+        dateYtbid <- as.character(format(StandardizedDate,
+                                         formatDateGeneric))
 
       }
 
-      sourceYtbid %>>%
-          super$setSource()
+      super$setSource(sourceYtbid)
 
-      super$getSource() %>>%
-        super$setData()
+      super$setData(super$getSource())
 
       lista <- list(source = super$getSource(),
                     date = dateYtbid)
@@ -473,8 +444,11 @@ ExtractorYtbid <- R6Class(
 
       error = function(e) {
 
-        message("[ExtractorYtbid][obtainSource][Error] exportJSON: ",
-                  self$getId(), " " , paste(e))
+        bdpar.log(message = paste0("exportJSON: ",
+                                   self$getId(), " " , paste(e)),
+                  level = "ERROR",
+                  className = class(self)[1],
+                  methodName = "obtainSource")
 
         lista <- list(source = "", date = dateYtbid)
         exportJSON <- rjson::toJSON(lista)
@@ -493,13 +467,44 @@ ExtractorYtbid <- R6Class(
           sep = "\n"
         )
       })
+    },
+    #'
+    #' @description Returns a \code{\link{character}} representing the instance
+    #'
+    #' @return \code{\link{Instance}} \code{\link{character}} representation
+    #'
+    toString = function() {
+      toRet <- paste0("\tPath: ", as.character(private$path),
+                      "\n\tDate: ", as.character(private$date),
+                      "\n\tIsValid: ", as.character(private$isValid),
+                      "\n\tSource: \"", as.character(private$source), "\"",
+                      "\n\tData: \"", as.character(private$data), "\"",
+                      "\n\tFlowPipes: ", paste(as.character(unlist(private$flowPipes)), collapse = " "),
+                      "\n\tBanPipes: ", paste(as.character(unlist(private$banPipes)), collapse = " "),
+                      "\n\tProperties: ")
 
-      return()
+      properties <- ""
+      if (length(private$properties) != 0) {
+        properties <- "\n\t\t"
+        properties <- paste0(properties, paste0(lapply(names(private$properties), function(propertyName) {
+          paste0("- ", propertyName, ": ",
+                 paste(as.character(unlist(private$properties[[propertyName]])), collapse = " "),
+                 collapse = "")
+        }), collapse = "\n\t\t"))
+      } else {
+        properties <- "Not located"
+      }
+      toRet <- paste0(toRet, properties, "\n")
+      toRet
     }
   ),
 
   private = list(
+    # A \code{\link{character}} value. ID of Youtube's comment.
     id = "",
+    # A \code{\link{character}} value. Path of the cache location. If it is NULL,
+    # checks if is defined in the \strong{"cache.youtube.path"} field of
+    # \emph{\link{bdpar.Options}} variable.
     cachePath = ""
   )
 )
