@@ -1,11 +1,13 @@
 testthat::context("AbbreviationPipe")
 
-testthat::setup(bdpar.Options$reset())
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -37,12 +39,19 @@ testthat::test_that("initialize",{
                                                resourcesAbbreviationsPath))
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+  bdpar.Options$set("verbose", TRUE)
+})
 
 testthat::test_that("initialize propertyName type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- NULL
   propertyLanguageName <- "language"
@@ -64,16 +73,22 @@ testthat::test_that("initialize propertyName type error",{
                                               notAfterDeps,
                                               replaceAbbreviations,
                                               resourcesAbbreviationsPath),
-                         "[AbbreviationPipe][initialize][Error] Checking the type of the 'propertyName' variable: NULL",
+                         "[AbbreviationPipe][initialize][FATAL] Checking the type of the 'propertyName' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize propertyLanguageName type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "abbreviation"
   propertyLanguageName <- NULL
@@ -95,16 +110,22 @@ testthat::test_that("initialize propertyLanguageName type error",{
                                               notAfterDeps,
                                               replaceAbbreviations,
                                               resourcesAbbreviationsPath),
-                         "[AbbreviationPipe][initialize][Error] Checking the type of the 'propertyLanguageName' variable: NULL",
+                         "[AbbreviationPipe][initialize][FATAL] Checking the type of the 'propertyLanguageName' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize alwaysBeforeDeps type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
@@ -126,16 +147,22 @@ testthat::test_that("initialize alwaysBeforeDeps type error",{
                                               notAfterDeps,
                                               replaceAbbreviations,
                                               resourcesAbbreviationsPath),
-                         "[AbbreviationPipe][initialize][Error] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
+                         "[AbbreviationPipe][initialize][FATAL] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize notAfterDeps type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
@@ -157,16 +184,22 @@ testthat::test_that("initialize notAfterDeps type error",{
                                               notAfterDeps,
                                               replaceAbbreviations,
                                               resourcesAbbreviationsPath),
-                         "[AbbreviationPipe][initialize][Error] Checking the type of the 'notAfterDeps' variable: NULL",
+                         "[AbbreviationPipe][initialize][FATAL] Checking the type of the 'notAfterDeps' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize replaceAbbreviations type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
@@ -188,16 +221,22 @@ testthat::test_that("initialize replaceAbbreviations type error",{
                                               notAfterDeps,
                                               replaceAbbreviations,
                                               resourcesAbbreviationsPath),
-                         "[AbbreviationPipe][initialize][Error] Checking the type of the 'replaceAbbreviations' variable: NULL",
+                         "[AbbreviationPipe][initialize][FATAL] Checking the type of the 'replaceAbbreviations' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize resourcesAbbreviationsPath type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
@@ -214,7 +253,7 @@ testthat::test_that("initialize resourcesAbbreviationsPath type error",{
                                               notAfterDeps,
                                               replaceAbbreviations,
                                               resourcesAbbreviationsPath),
-                         "[AbbreviationPipe][initialize][Error] Path of abbreviations resources is neither defined in initialize or in bdpar.Options",
+                         "[AbbreviationPipe][initialize][FATAL] Path of abbreviations resources is neither defined in initialize or in bdpar.Options",
                          fixed = TRUE)
 
   resourcesAbbreviationsPath <- 1
@@ -225,17 +264,23 @@ testthat::test_that("initialize resourcesAbbreviationsPath type error",{
                                               notAfterDeps,
                                               replaceAbbreviations,
                                               resourcesAbbreviationsPath),
-                         "[AbbreviationPipe][initialize][Error] Checking the type of the 'resourcesAbbreviationsPath' variable: numeric",
+                         "[AbbreviationPipe][initialize][FATAL] Checking the type of the 'resourcesAbbreviationsPath' variable: numeric",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -273,13 +318,19 @@ testthat::test_that("pipe",{
                          "Admin.")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe data empty",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -312,17 +363,22 @@ testthat::test_that("pipe data empty",{
   instance$addProperties("en","language")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[AbbreviationPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testAbbreviationPipe\\/testFile\\.tsms has data empty on pipe Abbreviation")
-
+                           "\\[AbbreviationPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testAbbreviationPipe\\/testFile\\.tsms has data empty on pipe Abbreviation")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe wihtout json file",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -355,16 +411,22 @@ testthat::test_that("pipe wihtout json file",{
   instance$addProperties("en","language")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[AbbreviationPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testAbbreviationPipe\\/testFile\\.tsms has not an abbreviationsJsonFile to apply to the language ->en")
+                           "\\[AbbreviationPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testAbbreviationPipe\\/testFile\\.tsms has not an abbreviationsJsonFile to apply to the language ->en")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe wihtout language property",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -396,17 +458,22 @@ testthat::test_that("pipe wihtout language property",{
   instance$setData("D. something")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[AbbreviationPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testAbbreviationPipe\\/testFile\\.tsms has not language property")
-
+                           "\\[AbbreviationPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testAbbreviationPipe\\/testFile\\.tsms has not language property")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe instance type error",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -432,17 +499,23 @@ testthat::test_that("pipe instance type error",{
   instance <- NULL
 
   testthat::expect_error(pipe$pipe(instance),
-                         "[AbbreviationPipe][pipe][Error] Checking the type of the 'instance' variable: NULL",
+                         "[AbbreviationPipe][pipe][FATAL] Checking the type of the 'instance' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findAbbreviation",{
   testthat::skip_if_not_installed("rex")
   testthat::skip_if_not_installed("rjson")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -474,13 +547,19 @@ testthat::test_that("findAbbreviation",{
                          TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findAbbreviation abbreviation type error",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -508,17 +587,23 @@ testthat::test_that("findAbbreviation abbreviation type error",{
 
   testthat::expect_error(pipe$findAbbreviation(data,
                                      abbreviation),
-                         "[AbbreviationPipe][findAbbreviation][Error] Checking the type of the 'abbreviation' variable: NULL",
+                         "[AbbreviationPipe][findAbbreviation][FATAL] Checking the type of the 'abbreviation' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findAbbreviation data type error",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -546,17 +631,23 @@ testthat::test_that("findAbbreviation data type error",{
   data <- NULL
 
   testthat::expect_error(pipe$findAbbreviation(data, abbreviation),
-                         "[AbbreviationPipe][findAbbreviation][Error] Checking the type of the 'data' variable: NULL",
+                         "[AbbreviationPipe][findAbbreviation][FATAL] Checking the type of the 'data' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("replaceAbbreviation ",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -590,13 +681,19 @@ testthat::test_that("replaceAbbreviation ",{
                          " Don  something")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("replaceAbbreviation abbreviation type error",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -627,17 +724,23 @@ testthat::test_that("replaceAbbreviation abbreviation type error",{
   testthat::expect_error(pipe$replaceAbbreviation(abbreviation,
                                                   extendedAbbreviation,
                                                   data),
-                         "[AbbreviationPipe][replaceAbbreviation][Error] Checking the type of the 'abbreviation' variable: NULL",
+                         "[AbbreviationPipe][replaceAbbreviation][FATAL] Checking the type of the 'abbreviation' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("replaceAbbreviation extendedAbbreviation type error",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -668,17 +771,23 @@ testthat::test_that("replaceAbbreviation extendedAbbreviation type error",{
   testthat::expect_error(pipe$replaceAbbreviation(abbreviation,
                                                   extendedAbbreviation,
                                                   data),
-                         "[AbbreviationPipe][replaceAbbreviation][Error] Checking the type of the 'extendedAbbreviation' variable: NULL",
+                         "[AbbreviationPipe][replaceAbbreviation][FATAL] Checking the type of the 'extendedAbbreviation' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("replaceAbbreviation data type error",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -709,17 +818,23 @@ testthat::test_that("replaceAbbreviation data type error",{
   testthat::expect_error(pipe$replaceAbbreviation(abbreviation,
                                                   extendedAbbreviation,
                                                   data),
-                         "[AbbreviationPipe][replaceAbbreviation][Error] Checking the type of the 'data' variable: NULL",
+                         "[AbbreviationPipe][replaceAbbreviation][FATAL] Checking the type of the 'data' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("getPropertyLanguageName",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -747,13 +862,19 @@ testthat::test_that("getPropertyLanguageName",{
                          "language")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("getResourcesAbbreviationsPath",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -787,13 +908,19 @@ testthat::test_that("getResourcesAbbreviationsPath",{
                          path)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("setResourcesAbbreviationsPath",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -827,13 +954,19 @@ testthat::test_that("setResourcesAbbreviationsPath",{
                          path)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("setResourcesAbbreviationsPath path type error",{
   testthat::skip_if_not_installed("rjson")
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   propertyName <- "abbreviation"
   propertyLanguageName <- "language"
   alwaysBeforeDeps <- list()
@@ -860,8 +993,11 @@ testthat::test_that("setResourcesAbbreviationsPath path type error",{
   path <- NULL
 
   testthat::expect_error(pipe$setResourcesAbbreviationsPath(path),
-                         "[AbbreviationPipe][setResourcesAbbreviationsPath][Error] Checking the type of the 'path' variable: NULL",
+                         "[AbbreviationPipe][setResourcesAbbreviationsPath][FATAL] Checking the type of the 'path' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
