@@ -1,14 +1,27 @@
 testthat::context("Instance")
 
-test_that("initialize",{
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::test_that("initialize",{
 
   path <- "example.tsms"
 
   instance <- Instance$new(path)
   testthat::expect_equal(instance$.__enclos_env__$private$path,
                         path)
-  testthat::expect_equal(instance$.__enclos_env__$private$properties,
-                        list(Initial_path = path))
+})
+
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
 })
 
 testthat::test_that("initialize path type error",{
@@ -16,28 +29,58 @@ testthat::test_that("initialize path type error",{
   path <- NULL
 
   testthat::expect_error(Instance$new(path),
-                         "[Instance][initialize][Error] Checking the type of the 'path' variable: NULL",
+                         "[Instance][initialize][FATAL] Checking the type of the 'path' variable: NULL",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("obtainDate",{
 
   path <- "example.tsms"
 
   testthat::expect_error(Instance$new(path)$obtainDate(),
-                         "[Instance][obtainDate][Error] I am an abstract interface method",
+                         "[Instance][obtainDate][FATAL] I am an abstract interface method",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("obtainSource",{
 
   path <- "example.tsms"
 
   testthat::expect_error(Instance$new(path)$obtainSource(),
-                         "[Instance][obtainSource][Error] I am an abstract interface method",
+                         "[Instance][obtainSource][FATAL] I am an abstract interface method",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("getDate",{
 
   path <- "example.tsms"
@@ -47,6 +90,16 @@ testthat::test_that("getDate",{
                          "")
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("getSource",{
 
   path <- "example.tsms"
@@ -56,6 +109,16 @@ testthat::test_that("getSource",{
                          "")
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("getPath",{
 
   path <- "example.tsms"
@@ -65,6 +128,16 @@ testthat::test_that("getPath",{
                          path)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("getData",{
 
   path <- "example.tsms"
@@ -74,13 +147,33 @@ testthat::test_that("getData",{
                          "")
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("getProperties",{
 
   path <- "example.tsms"
 
   instance <- Instance$new(path)
   testthat::expect_equal(instance$getProperties(),
-                        list(Initial_path = path))
+                         list())
+})
+
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
 })
 
 testthat::test_that("setSource",{
@@ -96,17 +189,14 @@ testthat::test_that("setSource",{
                         sourceExpected)
 })
 
-testthat::test_that("setSource source type error",{
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
-  path <- "example.tsms"
-
-  instance <- Instance$new(path)
-
-  sourceExpected <- NULL
-
-  testthat::expect_error(instance$setSource(sourceExpected),
-                         "[Instance][setSource][Error] Checking the type of the 'source' variable: NULL",
-                         fixed = TRUE)
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
 })
 
 testthat::test_that("setDate",{
@@ -122,6 +212,16 @@ testthat::test_that("setDate",{
                          dateExpected)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("setDate source type error",{
 
   path <- "example.tsms"
@@ -131,10 +231,20 @@ testthat::test_that("setDate source type error",{
   dateExpected <- NULL
 
   testthat::expect_error(instance$setDate(dateExpected),
-                         "[Instance][setDate][Error] Checking the type of the 'date' variable: NULL",
+                         "[Instance][setDate][FATAL] Checking the type of the 'date' variable: NULL",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("setProperties",{
 
   path <- "example.tsms"
@@ -148,6 +258,16 @@ testthat::test_that("setProperties",{
                          propertiesExpected)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("setProperties source type error",{
 
   path <- "example.tsms"
@@ -157,10 +277,20 @@ testthat::test_that("setProperties source type error",{
   propertiesExpected <- NULL
 
   testthat::expect_error(instance$setProperties(propertiesExpected),
-                         "[Instance][setProperties][Error] Checking the type of the 'properties' variable: NULL",
+                         "[Instance][setProperties][FATAL] Checking the type of the 'properties' variable: NULL",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("addProperties",{
 
   path <- "example.tsms"
@@ -172,7 +302,17 @@ testthat::test_that("addProperties",{
 
   instance$addProperties(valueExpected, nameExpected)
   testthat::expect_equal(instance$getProperties(),
-                         list(Initial_path = path, nameExpected = valueExpected))
+                         list(nameExpected = valueExpected))
+})
+
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
 })
 
 testthat::test_that("addProperties propertyName type error",{
@@ -185,20 +325,43 @@ testthat::test_that("addProperties propertyName type error",{
   nameExpected <- NULL
 
   testthat::expect_error(instance$addProperties(valueExpected, nameExpected),
-                         "[Instance][addProperties][Error] Checking the type of the 'propertyName' variable: NULL",
+                         "[Instance][addProperties][FATAL] Checking the type of the 'propertyName' variable: NULL",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("getSpecificProperty",{
 
   path <- "example.tsms"
 
   instance <- Instance$new(path)
 
-  nameExpected <- "Initial_path"
+  valueExpected <- "valueExpected"
+  nameExpected <- "nameExpected"
+
+  instance$addProperties(valueExpected, nameExpected)
 
   testthat::expect_equal(instance$getSpecificProperty(nameExpected),
-                         path)
+                         valueExpected)
+})
+
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
 })
 
 testthat::test_that("getSpecificProperty propertyName type error",{
@@ -210,22 +373,45 @@ testthat::test_that("getSpecificProperty propertyName type error",{
   nameExpected <- NULL
 
   testthat::expect_error(instance$getSpecificProperty(nameExpected),
-                         "[Instance][getSpecificProperty][Error] Checking the type of the 'propertyName' variable: NULL",
+                         "[Instance][getSpecificProperty][FATAL] Checking the type of the 'propertyName' variable: NULL",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("isSpecificProperty TRUE",{
 
   path <- "example.tsms"
 
   instance <- Instance$new(path)
 
-  nameExpected <- "Initial_path"
+  valueExpected <- "valueExpected"
+  nameExpected <- "nameExpected"
+
+  instance$addProperties(valueExpected, nameExpected)
 
   testthat::expect_equal(instance$isSpecificProperty(nameExpected),
                          TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("isSpecificProperty FALSE",{
 
   path <- "example.tsms"
@@ -238,6 +424,16 @@ testthat::test_that("isSpecificProperty FALSE",{
                          FALSE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("setSpecificProperty",{
 
   path <- "example.tsms"
@@ -252,6 +448,16 @@ testthat::test_that("setSpecificProperty",{
                          valueExpected)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("setSpecificProperty propertyName type error",{
 
   path <- "example.tsms"
@@ -262,19 +468,44 @@ testthat::test_that("setSpecificProperty propertyName type error",{
   valueExpected <- "valueExpected"
 
   testthat::expect_error(instance$setSpecificProperty(nameExpected, valueExpected),
-                         "[Instance][setSpecificProperty][Error] Checking the type of the 'propertyName' variable: NULL",
+                         "[Instance][setSpecificProperty][FATAL] Checking the type of the 'propertyName' variable: NULL",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("getNamesOfProperties",{
 
   path <- "example.tsms"
 
   instance <- Instance$new(path)
+
+  valueExpected <- "valueExpected"
+  nameExpected <- "nameExpected"
+
+  instance$addProperties(valueExpected, nameExpected)
+
   testthat::expect_equal(instance$getNamesOfProperties(),
-                         c("Initial_path"))
+                         c(nameExpected))
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("setData",{
 
@@ -289,17 +520,14 @@ testthat::test_that("setData",{
                          dataExpected)
 })
 
-testthat::test_that("setData source type error",{
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
-  path <- "example.tsms"
-
-  instance <- Instance$new(path)
-
-  dataExpected <- NULL
-
-  testthat::expect_error(instance$setData(dataExpected),
-                         "[Instance][setData][Error] Checking the type of the 'data' variable: NULL",
-                         fixed = TRUE)
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
 })
 
 testthat::test_that("isInstanceValid",{
@@ -311,6 +539,16 @@ testthat::test_that("isInstanceValid",{
                          TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("invalidate",{
 
   path <- "example.tsms"
@@ -323,6 +561,16 @@ testthat::test_that("invalidate",{
                          FALSE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("getFlowPipes",{
 
   path <- "example.tsms"
@@ -332,6 +580,16 @@ testthat::test_that("getFlowPipes",{
                          list())
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("addFlowPipes",{
 
   path <- "example.tsms"
@@ -345,6 +603,16 @@ testthat::test_that("addFlowPipes",{
                          list(nameExpected))
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("addFlowPipes namePipe type error",{
 
   path <- "example.tsms"
@@ -354,10 +622,20 @@ testthat::test_that("addFlowPipes namePipe type error",{
   nameExpected <- NULL
 
   testthat::expect_error(instance$addFlowPipes(nameExpected),
-                         "[Instance][addFlowPipes][Error] Checking the type of the 'namePipe' variable: NULL",
+                         "[Instance][addFlowPipes][FATAL] Checking the type of the 'namePipe' variable: NULL",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("getBanPipes",{
 
   path <- "example.tsms"
@@ -367,6 +645,15 @@ testthat::test_that("getBanPipes",{
                          c())
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("addBanPipes",{
 
@@ -381,6 +668,16 @@ testthat::test_that("addBanPipes",{
                          c(nameExpected))
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("addBanPipes namePipe type error",{
 
   path <- "example.tsms"
@@ -390,10 +687,20 @@ testthat::test_that("addBanPipes namePipe type error",{
   nameExpected <- 1
 
   testthat::expect_error(instance$addBanPipes(nameExpected),
-                         "[Instance][addBanPipes][Error] Checking the type of the 'namePipe' variable: numeric",
+                         "[Instance][addBanPipes][FATAL] Checking the type of the 'namePipe' variable: numeric",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("checkCompatibility TRUE",{
 
   path <- "example.tsms"
@@ -407,6 +714,16 @@ testthat::test_that("checkCompatibility TRUE",{
                          TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("checkCompatibility FALSE alwaysBefore",{
 
   path <- "example.tsms"
@@ -420,6 +737,16 @@ testthat::test_that("checkCompatibility FALSE alwaysBefore",{
                          FALSE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("checkCompatibility FALSE banAfter",{
 
   path <- "example.tsms"
@@ -433,6 +760,16 @@ testthat::test_that("checkCompatibility FALSE banAfter",{
                          FALSE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("checkCompatibility namePipe type error",{
 
   path <- "example.tsms"
@@ -443,10 +780,20 @@ testthat::test_that("checkCompatibility namePipe type error",{
   alwaysBefore <- list()
 
   testthat::expect_error(instance$checkCompatibility(nameExpected, alwaysBefore),
-                         "[Instance][checkCompatibility][Error] Checking the type of the 'namePipe' variable: NULL",
+                         "[Instance][checkCompatibility][FATAL] Checking the type of the 'namePipe' variable: NULL",
                          fixed = TRUE)
 })
 
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
 testthat::test_that("checkCompatibility namePipe type error",{
 
   path <- "example.tsms"
@@ -457,6 +804,32 @@ testthat::test_that("checkCompatibility namePipe type error",{
   alwaysBefore <- NULL
 
   testthat::expect_error(instance$checkCompatibility(nameExpected, alwaysBefore),
-                         "[Instance][checkCompatibility][Error] Checking the type of the 'alwaysBefore' variable: NULL",
+                         "[Instance][checkCompatibility][FATAL] Checking the type of the 'alwaysBefore' variable: NULL",
                          fixed = TRUE)
 })
+
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::test_that("toString basic works",{
+
+  path <- "example.tsms"
+
+  instance <- Instance$new(path)
+
+  testthat::expect_equal(instance$toString(),
+                         "",
+                         fixed = TRUE)
+})
+
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
