@@ -1,10 +1,12 @@
 testthat::context("InterjectionPipe")
 
-testthat::setup(bdpar.Options$reset())
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -37,12 +39,18 @@ testthat::test_that("initialize",{
                                                resourcesInterjectionsPath))
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize propertyName type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- NULL
   propertyLanguageName <- "language"
@@ -64,16 +72,22 @@ testthat::test_that("initialize propertyName type error",{
                                               notAfterDeps,
                                               removeInterjections,
                                               resourcesInterjectionsPath),
-                         "[InterjectionPipe][initialize][Error] Checking the type of the 'propertyName' variable: NULL",
+                         "[InterjectionPipe][initialize][FATAL] Checking the type of the 'propertyName' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize propertyLanguageName type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- NULL
@@ -95,16 +109,22 @@ testthat::test_that("initialize propertyLanguageName type error",{
                                               notAfterDeps,
                                               removeInterjections,
                                               resourcesInterjectionsPath),
-                         "[InterjectionPipe][initialize][Error] Checking the type of the 'propertyLanguageName' variable: NULL",
+                         "[InterjectionPipe][initialize][FATAL] Checking the type of the 'propertyLanguageName' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize alwaysBeforeDeps type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -126,16 +146,22 @@ testthat::test_that("initialize alwaysBeforeDeps type error",{
                                               notAfterDeps,
                                               removeInterjections,
                                               resourcesInterjectionsPath),
-                         "[InterjectionPipe][initialize][Error] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
+                         "[InterjectionPipe][initialize][FATAL] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize notAfterDeps type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -157,16 +183,22 @@ testthat::test_that("initialize notAfterDeps type error",{
                                               notAfterDeps,
                                               removeInterjections,
                                               resourcesInterjectionsPath),
-                         "[InterjectionPipe][initialize][Error] Checking the type of the 'notAfterDeps' variable: NULL",
+                         "[InterjectionPipe][initialize][FATAL] Checking the type of the 'notAfterDeps' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize removeInterjections type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -188,15 +220,22 @@ testthat::test_that("initialize removeInterjections type error",{
                                               notAfterDeps,
                                               removeInterjections,
                                               resourcesInterjectionsPath),
-                         "[InterjectionPipe][initialize][Error] Checking the type of the 'removeInterjections' variable: NULL",
+                         "[InterjectionPipe][initialize][FATAL] Checking the type of the 'removeInterjections' variable: NULL",
                          fixed = TRUE)
 })
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize resourcesInterjectionsPath type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -214,7 +253,7 @@ testthat::test_that("initialize resourcesInterjectionsPath type error",{
                                               notAfterDeps,
                                               removeInterjections,
                                               resourcesInterjectionsPath),
-                         "[InterjectionPipe][initialize][Error] Path of interjections resources is neither defined in initialize or in bdpar.Options",
+                         "[InterjectionPipe][initialize][FATAL] Path of interjections resources is neither defined in initialize or in bdpar.Options",
                          fixed = TRUE)
 
   resourcesInterjectionsPath <- 1
@@ -225,15 +264,22 @@ testthat::test_that("initialize resourcesInterjectionsPath type error",{
                                               notAfterDeps,
                                               removeInterjections,
                                               resourcesInterjectionsPath),
-                         "[InterjectionPipe][initialize][Error] Checking the type of the 'resourcesInterjectionsPath' variable: numeric",
+                         "[InterjectionPipe][initialize][FATAL] Checking the type of the 'resourcesInterjectionsPath' variable: numeric",
                          fixed = TRUE)
 })
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -249,8 +295,6 @@ testthat::test_that("pipe",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -270,12 +314,18 @@ testthat::test_that("pipe",{
   testthat::expect_equal(instance$getSpecificProperty("interjection"), c("yeah", "like"))
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe data empty",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -291,8 +341,6 @@ testthat::test_that("pipe data empty",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -309,15 +357,21 @@ testthat::test_that("pipe data empty",{
   instance$addProperties("en","language")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[InterjectionPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testInterjectionPipe\\/testFile\\.tsms has data empty on pipe Interjection")
+                           "\\[InterjectionPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testInterjectionPipe\\/testFile\\.tsms has data empty on pipe Interjection")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe wihtout json file",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -333,8 +387,6 @@ testthat::test_that("pipe wihtout json file",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -351,15 +403,21 @@ testthat::test_that("pipe wihtout json file",{
   instance$addProperties("en","language")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[InterjectionPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testInterjectionPipe\\/testFile\\.tsms has not an interjectionsJsonFile to apply to the language ->en")
+                           "\\[InterjectionPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testInterjectionPipe\\/testFile\\.tsms has not an interjectionsJsonFile to apply to the language ->en")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe wihtout language property",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -375,8 +433,6 @@ testthat::test_that("pipe wihtout language property",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -392,15 +448,21 @@ testthat::test_that("pipe wihtout language property",{
   instance$setData("yeah I like it")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[InterjectionPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testInterjectionPipe\\/testFile\\.tsms has not language property")
+                           "\\[InterjectionPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testInterjectionPipe\\/testFile\\.tsms has not language property")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe instance type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -416,8 +478,6 @@ testthat::test_that("pipe instance type error",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -428,16 +488,22 @@ testthat::test_that("pipe instance type error",{
   instance <- NULL
 
   testthat::expect_error(pipe$pipe(instance),
-                         "[InterjectionPipe][pipe][Error] Checking the type of the 'instance' variable: NULL",
+                         "[InterjectionPipe][pipe][FATAL] Checking the type of the 'instance' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findInterjection",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -453,8 +519,6 @@ testthat::test_that("findInterjection",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -470,12 +534,18 @@ testthat::test_that("findInterjection",{
                          TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findInterjection interjection type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -491,8 +561,6 @@ testthat::test_that("findInterjection interjection type error",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -505,16 +573,22 @@ testthat::test_that("findInterjection interjection type error",{
 
   testthat::expect_error(pipe$findInterjection(data,
                                                interjection),
-                         "[InterjectionPipe][findInterjection][Error] Checking the type of the 'interjection' variable: NULL",
+                         "[InterjectionPipe][findInterjection][FATAL] Checking the type of the 'interjection' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findInterjection data type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -530,8 +604,6 @@ testthat::test_that("findInterjection data type error",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -544,16 +616,22 @@ testthat::test_that("findInterjection data type error",{
 
   testthat::expect_error(pipe$findInterjection(data,
                                                interjection),
-                         "[InterjectionPipe][findInterjection][Error] Checking the type of the 'data' variable: NULL",
+                         "[InterjectionPipe][findInterjection][FATAL] Checking the type of the 'data' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("removeInterjection ",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -569,8 +647,6 @@ testthat::test_that("removeInterjection ",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -586,12 +662,18 @@ testthat::test_that("removeInterjection ",{
                          " I like it")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("removeInterjection abbreviation type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -607,8 +689,6 @@ testthat::test_that("removeInterjection abbreviation type error",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -621,16 +701,22 @@ testthat::test_that("removeInterjection abbreviation type error",{
 
   testthat::expect_error(pipe$removeInterjection(interjection,
                                                  data),
-                         "[InterjectionPipe][removeInterjection][Error] Checking the type of the 'interjection' variable: NULL",
+                         "[InterjectionPipe][removeInterjection][FATAL] Checking the type of the 'interjection' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("removeInterjection data type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -646,8 +732,6 @@ testthat::test_that("removeInterjection data type error",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -660,16 +744,22 @@ testthat::test_that("removeInterjection data type error",{
 
   testthat::expect_error(pipe$removeInterjection(interjection,
                                                  data),
-                         "[InterjectionPipe][removeInterjection][Error] Checking the type of the 'data' variable: NULL",
+                         "[InterjectionPipe][removeInterjection][FATAL] Checking the type of the 'data' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("getPropertyLanguageName",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -685,8 +775,6 @@ testthat::test_that("getPropertyLanguageName",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -698,12 +786,18 @@ testthat::test_that("getPropertyLanguageName",{
                          "language")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("getResourcesInterjectionsPath",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -719,8 +813,6 @@ testthat::test_that("getResourcesInterjectionsPath",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -738,12 +830,18 @@ testthat::test_that("getResourcesInterjectionsPath",{
                          path)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("setResourcesInterjectionsPath",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -759,8 +857,6 @@ testthat::test_that("setResourcesInterjectionsPath",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -778,12 +874,18 @@ testthat::test_that("setResourcesInterjectionsPath",{
                          path)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("setResourcesInterjectionsPath path type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "interjection"
   propertyLanguageName <- "language"
@@ -799,8 +901,6 @@ testthat::test_that("setResourcesInterjectionsPath path type error",{
   bdpar.Options$set(key = "resources.interjections.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- InterjectionPipe$new(propertyName,
                                propertyLanguageName,
                                alwaysBeforeDeps,
@@ -811,8 +911,11 @@ testthat::test_that("setResourcesInterjectionsPath path type error",{
   path <- NULL
 
   testthat::expect_error(pipe$setResourcesInterjectionsPath(path),
-                         "[InterjectionPipe][setResourcesInterjectionsPath][Error] Checking the type of the 'path' variable: NULL",
+                         "[InterjectionPipe][setResourcesInterjectionsPath][FATAL] Checking the type of the 'path' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
