@@ -1,10 +1,12 @@
 testthat::context("SlangPipe")
 
-testthat::teardown(bdpar.Options$reset())
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -37,12 +39,18 @@ testthat::test_that("initialize",{
                                         resourcesSlangsPath))
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize propertyName type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- NULL
   propertyLanguageName <- "language"
@@ -64,16 +72,22 @@ testthat::test_that("initialize propertyName type error",{
                                        notAfterDeps,
                                        replaceSlangs,
                                        resourcesSlangsPath),
-                         "[SlangPipe][initialize][Error] Checking the type of the 'propertyName' variable: NULL",
+                         "[SlangPipe][initialize][FATAL] Checking the type of the 'propertyName' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize propertyLanguageName type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- NULL
@@ -95,16 +109,22 @@ testthat::test_that("initialize propertyLanguageName type error",{
                                        notAfterDeps,
                                        replaceSlangs,
                                        resourcesSlangsPath),
-                         "[SlangPipe][initialize][Error] Checking the type of the 'propertyLanguageName' variable: NULL",
+                         "[SlangPipe][initialize][FATAL] Checking the type of the 'propertyLanguageName' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize alwaysBeforeDeps type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -126,16 +146,22 @@ testthat::test_that("initialize alwaysBeforeDeps type error",{
                                        notAfterDeps,
                                        replaceSlangs,
                                        resourcesSlangsPath),
-                         "[SlangPipe][initialize][Error] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
+                         "[SlangPipe][initialize][FATAL] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize notAfterDeps type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -157,16 +183,22 @@ testthat::test_that("initialize notAfterDeps type error",{
                                        notAfterDeps,
                                        replaceSlangs,
                                        resourcesSlangsPath),
-                         "[SlangPipe][initialize][Error] Checking the type of the 'notAfterDeps' variable: NULL",
+                         "[SlangPipe][initialize][FATAL] Checking the type of the 'notAfterDeps' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize replaceSlangs type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -188,16 +220,22 @@ testthat::test_that("initialize replaceSlangs type error",{
                                        notAfterDeps,
                                        replaceSlangs,
                                        resourcesSlangsPath),
-                         "[SlangPipe][initialize][Error] Checking the type of the 'replaceSlangs' variable: NULL",
+                         "[SlangPipe][initialize][FATAL] Checking the type of the 'replaceSlangs' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize resourcesSlangsPath type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -215,7 +253,7 @@ testthat::test_that("initialize resourcesSlangsPath type error",{
                                        notAfterDeps,
                                        replaceSlangs,
                                        resourcesSlangsPath),
-                         "[SlangPipe][initialize][Error] Path of slangs resources is neither defined in initialize or in bdpar.Options",
+                         "[SlangPipe][initialize][FATAL] Path of slangs resources is neither defined in initialize or in bdpar.Options",
                          fixed = TRUE)
 
   resourcesSlangsPath <- 1
@@ -226,16 +264,22 @@ testthat::test_that("initialize resourcesSlangsPath type error",{
                                        notAfterDeps,
                                        replaceSlangs,
                                        resourcesSlangsPath),
-                         "[SlangPipe][initialize][Error] Checking the type of the 'resourcesSlangsPath' variable: numeric",
+                         "[SlangPipe][initialize][FATAL] Checking the type of the 'resourcesSlangsPath' variable: numeric",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -251,8 +295,6 @@ testthat::test_that("pipe",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -279,13 +321,18 @@ testthat::test_that("pipe",{
                          "yur")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe data empty",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
-  testthat::skip_if_not_installed("readr")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -301,8 +348,6 @@ testthat::test_that("pipe data empty",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -325,17 +370,22 @@ testthat::test_that("pipe data empty",{
   pipe$setResourcesSlangsPath(path)
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[SlangPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testSlangPipe\\/testFile\\.tsms has data empty on pipe Slang")
+                           "\\[SlangPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testSlangPipe\\/testFile\\.tsms has data empty on pipe Slang")
 
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe wihtout json file",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
-  testthat::skip_if_not_installed("readr")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -351,8 +401,6 @@ testthat::test_that("pipe wihtout json file",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -369,17 +417,22 @@ testthat::test_that("pipe wihtout json file",{
   instance$addProperties("en","language")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[SlangPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testSlangPipe\\/testFile\\.tsms has not an SlangsJsonFile to apply to the language-> en")
+                           "\\[SlangPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testSlangPipe\\/testFile\\.tsms has not an SlangsJsonFile to apply to the language-> en")
 
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe wihtout language property",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
-  testthat::skip_if_not_installed("readr")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -395,8 +448,6 @@ testthat::test_that("pipe wihtout language property",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -412,17 +463,22 @@ testthat::test_that("pipe wihtout language property",{
   instance$setData("yur name")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[SlangPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testSlangPipe\\/testFile\\.tsms has not language property")
+                           "\\[SlangPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testSlangPipe\\/testFile\\.tsms has not language property")
 
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe instance type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
-  testthat::skip_if_not_installed("readr")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -438,8 +494,6 @@ testthat::test_that("pipe instance type error",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -450,16 +504,22 @@ testthat::test_that("pipe instance type error",{
   instance <- NULL
 
   testthat::expect_error(pipe$pipe(instance),
-                         "[SlangPipe][pipe][Error] Checking the type of the 'instance' variable: NULL",
+                         "[SlangPipe][pipe][FATAL] Checking the type of the 'instance' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findSlang",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -475,8 +535,6 @@ testthat::test_that("findSlang",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -492,12 +550,18 @@ testthat::test_that("findSlang",{
                          TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findSlang slang type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -513,8 +577,6 @@ testthat::test_that("findSlang slang type error",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -527,16 +589,22 @@ testthat::test_that("findSlang slang type error",{
 
   testthat::expect_error(pipe$findSlang(data,
                                         slang),
-                         "[SlangPipe][findSlang][Error] Checking the type of the 'slang' variable: NULL",
+                         "[SlangPipe][findSlang][FATAL] Checking the type of the 'slang' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findSlang data type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -552,8 +620,6 @@ testthat::test_that("findSlang data type error",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -566,16 +632,22 @@ testthat::test_that("findSlang data type error",{
 
   testthat::expect_error(pipe$findSlang(data,
                                         slang),
-                         "[SlangPipe][findSlang][Error] Checking the type of the 'data' variable: NULL",
+                         "[SlangPipe][findSlang][FATAL] Checking the type of the 'data' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("replaceSlang ",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -591,8 +663,6 @@ testthat::test_that("replaceSlang ",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -610,12 +680,18 @@ testthat::test_that("replaceSlang ",{
                          " your  name")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("replaceSlang slang type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -631,8 +707,6 @@ testthat::test_that("replaceSlang slang type error",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -647,16 +721,22 @@ testthat::test_that("replaceSlang slang type error",{
   testthat::expect_error(pipe$replaceSlang(slang,
                                            extendedSlang,
                                            data),
-                         "[SlangPipe][replaceSlang][Error] Checking the type of the 'slang' variable: NULL",
+                         "[SlangPipe][replaceSlang][FATAL] Checking the type of the 'slang' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("replaceSlang extendedSlang type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -672,8 +752,6 @@ testthat::test_that("replaceSlang extendedSlang type error",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -688,16 +766,22 @@ testthat::test_that("replaceSlang extendedSlang type error",{
   testthat::expect_error(pipe$replaceSlang(slang,
                                            extendedSlang,
                                            data),
-                         "[SlangPipe][replaceSlang][Error] Checking the type of the 'extendedSlang' variable: NULL",
+                         "[SlangPipe][replaceSlang][FATAL] Checking the type of the 'extendedSlang' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("replaceSlang data type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -713,8 +797,6 @@ testthat::test_that("replaceSlang data type error",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -729,16 +811,22 @@ testthat::test_that("replaceSlang data type error",{
   testthat::expect_error(pipe$replaceSlang(slang,
                                            extendedSlang,
                                            data),
-                         "[SlangPipe][replaceSlang][Error] Checking the type of the 'data' variable: NULL",
+                         "[SlangPipe][replaceSlang][FATAL] Checking the type of the 'data' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("getPropertyLanguageName",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -754,8 +842,6 @@ testthat::test_that("getPropertyLanguageName",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -767,12 +853,18 @@ testthat::test_that("getPropertyLanguageName",{
                          "language")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("getResourcesSlangsPath",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -788,8 +880,6 @@ testthat::test_that("getResourcesSlangsPath",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -807,12 +897,18 @@ testthat::test_that("getResourcesSlangsPath",{
                          path)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("setResourcesSlangsPath",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -828,8 +924,6 @@ testthat::test_that("setResourcesSlangsPath",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -848,12 +942,18 @@ testthat::test_that("setResourcesSlangsPath",{
                          path)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("setResourcesSlangsPath path type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "langpropname"
   propertyLanguageName <- "language"
@@ -869,8 +969,6 @@ testthat::test_that("setResourcesSlangsPath path type error",{
   bdpar.Options$set(key = "resources.slangs.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- SlangPipe$new(propertyName,
                         propertyLanguageName,
                         alwaysBeforeDeps,
@@ -881,8 +979,11 @@ testthat::test_that("setResourcesSlangsPath path type error",{
   path <- NULL
 
   testthat::expect_error(pipe$setResourcesSlangsPath(path),
-                         "[SlangPipe][setResourcesSlangsPath][Error] Checking the type of the 'path' variable: NULL",
+                         "[SlangPipe][setResourcesSlangsPath][FATAL] Checking the type of the 'path' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
