@@ -1,10 +1,12 @@
 testthat::context("StopWordPipe")
 
-testthat::setup(bdpar.Options$reset())
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -37,12 +39,18 @@ testthat::test_that("initialize",{
                                            resourcesStopWordsPath))
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize propertyName type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- NULL
   propertyLanguageName <- "language"
@@ -64,16 +72,22 @@ testthat::test_that("initialize propertyName type error",{
                                           notAfterDeps,
                                           removeStopWords,
                                           resourcesStopWordsPath),
-                         "[StopWordPipe][initialize][Error] Checking the type of the 'propertyName' variable: NULL",
+                         "[StopWordPipe][initialize][FATAL] Checking the type of the 'propertyName' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize propertyLanguageName type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- NULL
@@ -95,16 +109,22 @@ testthat::test_that("initialize propertyLanguageName type error",{
                                           notAfterDeps,
                                           removeStopWords,
                                           resourcesStopWordsPath),
-                         "[StopWordPipe][initialize][Error] Checking the type of the 'propertyLanguageName' variable: NULL",
+                         "[StopWordPipe][initialize][FATAL] Checking the type of the 'propertyLanguageName' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize alwaysBeforeDeps type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -126,16 +146,22 @@ testthat::test_that("initialize alwaysBeforeDeps type error",{
                                           notAfterDeps,
                                           removeStopWords,
                                           resourcesStopWordsPath),
-                         "[StopWordPipe][initialize][Error] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
+                         "[StopWordPipe][initialize][FATAL] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize notAfterDeps type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -157,16 +183,22 @@ testthat::test_that("initialize notAfterDeps type error",{
                                           notAfterDeps,
                                           removeStopWords,
                                           resourcesStopWordsPath),
-                         "[StopWordPipe][initialize][Error] Checking the type of the 'notAfterDeps' variable: NULL",
+                         "[StopWordPipe][initialize][FATAL] Checking the type of the 'notAfterDeps' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize removeStopWords type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -188,16 +220,22 @@ testthat::test_that("initialize removeStopWords type error",{
                                           notAfterDeps,
                                           removeStopWords,
                                           resourcesStopWordsPath),
-                         "[StopWordPipe][initialize][Error] Checking the type of the 'removeStopWords' variable: NULL",
+                         "[StopWordPipe][initialize][FATAL] Checking the type of the 'removeStopWords' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize resourcesStopWordsPath type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -215,7 +253,7 @@ testthat::test_that("initialize resourcesStopWordsPath type error",{
                                           notAfterDeps,
                                           removeStopWords,
                                           resourcesStopWordsPath),
-                         "[StopWordPipe][initialize][Error] Path of stop words resources is neither defined in initialize or in bdpar.Options",
+                         "[StopWordPipe][initialize][FATAL] Path of stop words resources is neither defined in initialize or in bdpar.Options",
                          fixed = TRUE)
 
   resourcesStopWordsPath <- 1
@@ -226,17 +264,22 @@ testthat::test_that("initialize resourcesStopWordsPath type error",{
                                           notAfterDeps,
                                           removeStopWords,
                                           resourcesStopWordsPath),
-                         "[StopWordPipe][initialize][Error] Checking the type of the 'resourcesStopWordsPath' variable: numeric",
+                         "[StopWordPipe][initialize][FATAL] Checking the type of the 'resourcesStopWordsPath' variable: numeric",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
-  testthat::skip_if_not_installed("readr")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -252,8 +295,6 @@ testthat::test_that("pipe",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -274,13 +315,18 @@ testthat::test_that("pipe",{
                          c("an","want","you"))
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe data empty",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
-  testthat::skip_if_not_installed("readr")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -296,8 +342,6 @@ testthat::test_that("pipe data empty",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -314,16 +358,21 @@ testthat::test_that("pipe data empty",{
   instance$addProperties("en","language")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[StopWordPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testStopWordPipe\\/testFile\\.tsms has data empty on pipe StopWord")
+                           "\\[StopWordPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testStopWordPipe\\/testFile\\.tsms has data empty on pipe StopWord")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe wihtout json file",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
-  testthat::skip_if_not_installed("readr")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -339,8 +388,6 @@ testthat::test_that("pipe wihtout json file",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -357,16 +404,21 @@ testthat::test_that("pipe wihtout json file",{
   instance$addProperties("en","language")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[StopWordPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testStopWordPipe\\/testFile\\.tsms has not an StopWordsJsonFile to apply to the language-> en")
+                           "\\[StopWordPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testStopWordPipe\\/testFile\\.tsms has not an StopWordsJsonFile to apply to the language-> en")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe wihtout language property",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
-  testthat::skip_if_not_installed("readr")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -382,8 +434,6 @@ testthat::test_that("pipe wihtout language property",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -399,16 +449,21 @@ testthat::test_that("pipe wihtout language property",{
   instance$setData("you want an apple")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[StopWordPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testStopWordPipe\\/testFile\\.tsms has not language property")
+                           "\\[StopWordPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testStopWordPipe\\/testFile\\.tsms has not language property")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe instance type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
-  testthat::skip_if_not_installed("readr")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -424,8 +479,6 @@ testthat::test_that("pipe instance type error",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -436,16 +489,22 @@ testthat::test_that("pipe instance type error",{
   instance <- NULL
 
   testthat::expect_error(pipe$pipe(instance),
-                         "[StopWordPipe][pipe][Error] Checking the type of the 'instance' variable: NULL",
+                         "[StopWordPipe][pipe][FATAL] Checking the type of the 'instance' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findStopWord",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -461,8 +520,6 @@ testthat::test_that("findStopWord",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -478,12 +535,18 @@ testthat::test_that("findStopWord",{
                          TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findStopWord stopWord type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -499,8 +562,6 @@ testthat::test_that("findStopWord stopWord type error",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -513,16 +574,22 @@ testthat::test_that("findStopWord stopWord type error",{
 
   testthat::expect_error(pipe$findStopWord(data,
                                            stopWord),
-                         "[StopWordPipe][findStopWord][Error] Checking the type of the 'stopWord' variable: NULL",
+                         "[StopWordPipe][findStopWord][FATAL] Checking the type of the 'stopWord' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findStopWord data type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -538,8 +605,6 @@ testthat::test_that("findStopWord data type error",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -552,16 +617,22 @@ testthat::test_that("findStopWord data type error",{
 
   testthat::expect_error(pipe$findStopWord(data,
                                            stopWord),
-                         "[StopWordPipe][findStopWord][Error] Checking the type of the 'data' variable: NULL",
+                         "[StopWordPipe][findStopWord][FATAL] Checking the type of the 'data' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("removeStopWord ",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -577,8 +648,6 @@ testthat::test_that("removeStopWord ",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -594,12 +663,18 @@ testthat::test_that("removeStopWord ",{
                          " want an apple")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("removeStopWord stopWord type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -615,8 +690,6 @@ testthat::test_that("removeStopWord stopWord type error",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -629,16 +702,22 @@ testthat::test_that("removeStopWord stopWord type error",{
 
   testthat::expect_error(pipe$removeStopWord(stopWord,
                                              data),
-                         "[StopWordPipe][removeStopWord][Error] Checking the type of the 'stopWord' variable: NULL",
+                         "[StopWordPipe][removeStopWord][FATAL] Checking the type of the 'stopWord' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("removeStopWord data type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -654,8 +733,6 @@ testthat::test_that("removeStopWord data type error",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -668,16 +745,22 @@ testthat::test_that("removeStopWord data type error",{
 
   testthat::expect_error(pipe$removeStopWord(stopWord,
                                              data),
-                         "[StopWordPipe][removeStopWord][Error] Checking the type of the 'data' variable: NULL",
+                         "[StopWordPipe][removeStopWord][FATAL] Checking the type of the 'data' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("getPropertyLanguageName",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -693,8 +776,6 @@ testthat::test_that("getPropertyLanguageName",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -706,12 +787,18 @@ testthat::test_that("getPropertyLanguageName",{
                          "language")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("getResourcesStopWordsPath",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -727,8 +814,6 @@ testthat::test_that("getResourcesStopWordsPath",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -746,12 +831,18 @@ testthat::test_that("getResourcesStopWordsPath",{
                          path)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("setResourcesStopWordsPath",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -767,8 +858,6 @@ testthat::test_that("setResourcesStopWordsPath",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -786,12 +875,18 @@ testthat::test_that("setResourcesStopWordsPath",{
                          path)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("setResourcesStopWordsPath path type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "stopWord"
   propertyLanguageName <- "language"
@@ -807,8 +902,6 @@ testthat::test_that("setResourcesStopWordsPath path type error",{
   bdpar.Options$set(key = "resources.stopwords.path",
                     value = path)
 
-  Bdpar$new()
-
   pipe <- StopWordPipe$new(propertyName,
                            propertyLanguageName,
                            alwaysBeforeDeps,
@@ -819,8 +912,11 @@ testthat::test_that("setResourcesStopWordsPath path type error",{
   path <- NULL
 
   testthat::expect_error(pipe$setResourcesStopWordsPath(path),
-                         "[StopWordPipe][setResourcesStopWordsPath][Error] Checking the type of the 'path' variable: NULL",
+                         "[StopWordPipe][setResourcesStopWordsPath][FATAL] Checking the type of the 'path' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
